@@ -23,24 +23,30 @@ AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
-# 抱歉，该帐户已经被锁定。
+# 抱歉，该账户已经被锁定。
 FAILEDOPERATION_ACCOUNTISLOCKED = 'FailedOperation.AccountIsLocked'
 
-# 您的帐号下包含个人豪华域名，不能直接升级，请联系销售。
+# 您的账户下包含个人豪华域名，不能直接升级，请联系销售。
 FAILEDOPERATION_CONTAINSPERSONALVIP = 'FailedOperation.ContainsPersonalVip'
 
 # 此优惠券只能被免费域名使用。
 FAILEDOPERATION_COUPONFORFREEDOMAIN = 'FailedOperation.CouponForFreeDomain'
 
-# 您的帐户不满足使用此优惠券的条件。
+# 您的账户不满足使用此优惠券的条件。
 FAILEDOPERATION_COUPONNOTSUPPORTED = 'FailedOperation.CouponNotSupported'
 
 # 域名已经使用过该类型的礼券了，不能重复使用。
 FAILEDOPERATION_COUPONTYPEALREADYUSED = 'FailedOperation.CouponTypeAlreadyUsed'
 
+# DNSSEC 未完全关闭，不允许添加 @ 子域名 CNAME、显性 URL 或者隐性 URL 记录。
+FAILEDOPERATION_DNSSECINCOMPLETECLOSED = 'FailedOperation.DNSSECIncompleteClosed'
+
 # 该域名已在您的列表中，无需重复添加。
 FAILEDOPERATION_DOMAINEXISTS = 'FailedOperation.DomainExists'
 
+# 该域名属于企业邮用户
+FAILEDOPERATION_DOMAININENTERPRISEMAILACCOUNT = 'FailedOperation.DomainInEnterpriseMailAccount'
+
 # 该域名为腾讯云 DNSPod 重点保护资源，为了避免误操作造成的业务影响，域名禁止自行操作删除。如果您确认需要删除域名，请先联系您的客户经理，我们将竭诚为您提供技术支持。
 FAILEDOPERATION_DOMAINISKEYDOMAIN = 'FailedOperation.DomainIsKeyDomain'
 
@@ -65,6 +71,12 @@ FAILEDOPERATION_DOMAINOWNEDBYOTHERUSER = 'FailedOperation.DomainOwnedByOtherUser
 # 校验公网 IP 发生异常。
 FAILEDOPERATION_EIPCHECKFAILED = 'FailedOperation.EipCheckFailed'
 
+# 文件不存在或文件还未生成
+FAILEDOPERATION_FILENOTEXIST = 'FailedOperation.FileNotExist'
+
+# 您操作过于频繁，请稍后重试
+FAILEDOPERATION_FREQUENCYLIMIT = 'FailedOperation.FrequencyLimit'
+
 # 此功能暂停申请，请稍候重试。
 FAILEDOPERATION_FUNCTIONNOTALLOWEDAPPLY = 'FailedOperation.FunctionNotAllowedApply'
 
@@ -74,7 +86,7 @@ FAILEDOPERATION_GETWHOISFAILED = 'FailedOperation.GetWhoisFailed'
 # 账户余额不足。
 FAILEDOPERATION_INSUFFICIENTBALANCE = 'FailedOperation.InsufficientBalance'
 
-# 帐号异地登录，请求被拒绝。
+# 账号异地登录，请求被拒绝。
 FAILEDOPERATION_LOGINAREANOTALLOWED = 'FailedOperation.LoginAreaNotAllowed'
 
 # 登录失败，请检查账号和密码是否正确。
@@ -86,6 +98,9 @@ FAILEDOPERATION_LOGINTIMEOUT = 'FailedOperation.LoginTimeout'
 # 用户手机没有通过验证。
 FAILEDOPERATION_MOBILENOTVERIFIED = 'FailedOperation.MobileNotVerified'
 
+# 请先添加默认线路的解析记录
+FAILEDOPERATION_MUSTADDDEFAULTLINEFIRST = 'FailedOperation.MustAddDefaultLineFirst'
+
 # 权限错误，您无法查看该任务的详情。
 FAILEDOPERATION_NOTBATCHTASKOWNER = 'FailedOperation.NotBatchTaskOwner'
 
@@ -140,9 +155,15 @@ INVALIDPARAMETER_ACTIONSUCCESS = 'InvalidParameter.ActionSuccess'
 # 用户未实名。
 INVALIDPARAMETER_ACTIVITY = 'InvalidParameter.Activity'
 
+# 该域名已在您的域名列表中，请删除后再添加到别名列表
+INVALIDPARAMETER_ALIASISMYDOMAIN = 'InvalidParameter.AliasIsMyDomain'
+
 # 创建批量域名任务失败，原因：内部错误。
 INVALIDPARAMETER_BATCHDOMAINCREATEACTIONERROR = 'InvalidParameter.BatchDomainCreateActionError'
 
+# 您有批量任务未执行完成，请等待完成后继续添加。
+INVALIDPARAMETER_BATCHLIMITUNDO = 'InvalidParameter.BatchLimitUndo'
+
 # 创建批量记录任务失败，原因：内部错误。
 INVALIDPARAMETER_BATCHRECORDCREATEACTIONERROR = 'InvalidParameter.BatchRecordCreateActionError'
 
@@ -158,7 +179,7 @@ INVALIDPARAMETER_BATCHRECORDREMOVEACTIONERROR = 'InvalidParameter.BatchRecordRem
 # 批量替换记录任务失败，原因：内部错误。
 INVALIDPARAMETER_BATCHRECORDREPLACEACTIONERROR = 'InvalidParameter.BatchRecordReplaceActionError'
 
-# 超过批量任务数上限。
+# 超过单个账号的批量任务数并发上限4个。
 INVALIDPARAMETER_BATCHTASKCOUNTLIMIT = 'InvalidParameter.BatchTaskCountLimit'
 
 # 任务不存在，无法获取任务详情。
@@ -173,6 +194,9 @@ INVALIDPARAMETER_BROWSERNULL = 'InvalidParameter.BrowserNull'
 # 您操作过于频繁，请稍后重试。
 INVALIDPARAMETER_COMMON = 'InvalidParameter.Common'
 
+# 您复制的线路已存在，无需重复复制。
+INVALIDPARAMETER_COPIEDLINEGROUPDUPLICATED = 'InvalidParameter.CopiedLineGroupDuplicated'
+
 # 自定义错误信息。
 INVALIDPARAMETER_CUSTOMMESSAGE = 'InvalidParameter.CustomMessage'
 
@@ -185,6 +209,9 @@ INVALIDPARAMETER_DATAINVALID = 'InvalidParameter.DataInvalid'
 # 订单类型无效。
 INVALIDPARAMETER_DEALTYPEINVALID = 'InvalidParameter.DealTypeInvalid'
 
+# 默认线路无法进行自定义线路分组。
+INVALIDPARAMETER_DEFAULTLINENOTSELFDEFINED = 'InvalidParameter.DefaultLineNotSelfdefined'
+
 # 域名已升级至付费套餐，无法完成下单。
 INVALIDPARAMETER_DNSDEALDOMAINUPGRADED = 'InvalidParameter.DnsDealDomainUpgraded'
 
@@ -206,6 +233,9 @@ INVALIDPARAMETER_DOMAINALIASIDINVALID = 'InvalidParameter.DomainAliasIdInvalid'
 # 域名编号不正确。
 INVALIDPARAMETER_DOMAINIDINVALID = 'InvalidParameter.DomainIdInvalid'
 
+# 该域名涉及违法违规黑名单，无法进行该操作
+INVALIDPARAMETER_DOMAININBLACKLIST = 'InvalidParameter.DomainInBlackList'
+
 # 不允许操作生效中或失效中的域名。
 INVALIDPARAMETER_DOMAININEFFECTORINVALIDATED = 'InvalidParameter.DomainInEffectOrInvalidated'
 
@@ -218,6 +248,9 @@ INVALIDPARAMETER_DOMAINISALIASER = 'InvalidParameter.DomainIsAliaser'
 # 该域名已有同类型操作未完成，无法执行该操作。
 INVALIDPARAMETER_DOMAINISMODIFYINGDNS = 'InvalidParameter.DomainIsModifyingDns'
 
+# 此域名是自己域名的别名
+INVALIDPARAMETER_DOMAINISMYALIAS = 'InvalidParameter.DomainIsMyAlias'
+
 # 域名没有锁定。
 INVALIDPARAMETER_DOMAINISNOTLOCKED = 'InvalidParameter.DomainIsNotlocked'
 
@@ -278,42 +311,102 @@ INVALIDPARAMETER_GRADENOTCOPY = 'InvalidParameter.GradeNotCopy'
 # 分组编号不正确。
 INVALIDPARAMETER_GROUPIDINVALID = 'InvalidParameter.GroupIdInvalid'
 
+# 分组名为空。
+INVALIDPARAMETER_GROUPNAMEEMPTY = 'InvalidParameter.GroupNameEmpty'
+
 # 同名分组已经存在。
 INVALIDPARAMETER_GROUPNAMEEXISTS = 'InvalidParameter.GroupNameExists'
 
 # 分组名为1-17个字符。
 INVALIDPARAMETER_GROUPNAMEINVALID = 'InvalidParameter.GroupNameInvalid'
 
+# 指定的分组名已存在，或为系统内置线路或自定义线路，无法用于分组名称。
+INVALIDPARAMETER_GROUPNAMEOCCUPIED = 'InvalidParameter.GroupNameOccupied'
+
 # 您已经提交过申请并且正在审核中，请耐心等候。
 INVALIDPARAMETER_HASPENDINGAPPLY = 'InvalidParameter.HasPendingApply'
 
 # 该订单存在冲突或参数有误，无法完成支付，请重新购买。
 INVALIDPARAMETER_ILLEGALNEWDEAL = 'InvalidParameter.IllegalNewDeal'
 
+# 任务不存在。
+INVALIDPARAMETER_INNERTASKNOTEXIST = 'InvalidParameter.InnerTaskNotExist'
+
 # 礼券代码无效。
 INVALIDPARAMETER_INVALIDCOUPON = 'InvalidParameter.InvalidCoupon'
 
 # 请输入正确的订单号。
 INVALIDPARAMETER_INVALIDDEALNAME = 'InvalidParameter.InvalidDealName'
 
+# 不是合法的IP段。
+INVALIDPARAMETER_INVALIDIP = 'InvalidParameter.InvalidIp'
+
 # 无效密钥 ID。
 INVALIDPARAMETER_INVALIDSECRETID = 'InvalidParameter.InvalidSecretId'
 
 # 无效签名。
 INVALIDPARAMETER_INVALIDSIGNATURE = 'InvalidParameter.InvalidSignature'
 
+# 源域名ID格式不正确。
+INVALIDPARAMETER_INVALIDSRCDOMAINID = 'InvalidParameter.InvalidSrcDomainId'
+
 # 无效的时间。
 INVALIDPARAMETER_INVALIDTIME = 'InvalidParameter.InvalidTime'
 
 # 权重不合法。请输入0~100的整数。
 INVALIDPARAMETER_INVALIDWEIGHT = 'InvalidParameter.InvalidWeight'
 
+# IP已经存在。
+INVALIDPARAMETER_IPALREADYEXIST = 'InvalidParameter.IpAlreadyExist'
+
+# 删除自定义线路失败，原因：线路不存在或者已删除。
+INVALIDPARAMETER_IPAREA = 'InvalidParameter.IpArea'
+
 # ips 过长。
 INVALIDPARAMETER_IPSEXCEEDLIMIT = 'InvalidParameter.IpsExceedLimit'
 
-# 单次任务数量超过上限。
+# 单次任务记录数量超过上限5000条。
 INVALIDPARAMETER_JOBGREATERTHANLIMIT = 'InvalidParameter.JobGreaterThanLimit'
 
+# 线路格式不正确。
+INVALIDPARAMETER_LINEFORMATINVALID = 'InvalidParameter.LineFormatInvalid'
+
+# 线路不存在，或者线路不支持自定义分组。
+INVALIDPARAMETER_LINEGROUPNOTSUPPORTED = 'InvalidParameter.LineGroupNotSupported'
+
+# 当前套餐的线路分组已达到数量上限。
+INVALIDPARAMETER_LINEGROUPOVERCOUNTED = 'InvalidParameter.LineGroupOverCounted'
+
+# 线路分组更新失败，原因：内部错误。
+INVALIDPARAMETER_LINEGROUPUPDATEFAILED = 'InvalidParameter.LineGroupUpdateFailed'
+
+# 线路已存在于其他分组中。
+INVALIDPARAMETER_LINEINANOTHERGROUP = 'InvalidParameter.LineInAnotherGroup'
+
+# 线路正在使用当中，无法修改名称。
+INVALIDPARAMETER_LINEINUSE = 'InvalidParameter.LineInUse'
+
+# 线路正在使用当中，无法删除名称。
+INVALIDPARAMETER_LINEINUSENOTDELETE = 'InvalidParameter.LineInUseNotDelete'
+
+# 线路名称的长度不能超过17个字符。
+INVALIDPARAMETER_LINENAMEINVALID = 'InvalidParameter.LineNameInvalid'
+
+# 线路名称包含不被接受的字符。
+INVALIDPARAMETER_LINENAMEINVALIDCHARACTER = 'InvalidParameter.LineNameInvalidCharacter'
+
+# 线路名是系统内置线路或用户自定义分组线路，无法使用该名称。
+INVALIDPARAMETER_LINENAMEOCCUPIED = 'InvalidParameter.LineNameOccupied'
+
+# 分组不存在，请确认是否已经被删除了。
+INVALIDPARAMETER_LINENOTEXIST = 'InvalidParameter.LineNotExist'
+
+# 您至少需要选择一个线路。
+INVALIDPARAMETER_LINENOTSELECTED = 'InvalidParameter.LineNotSelected'
+
+# 最多只能选择120个线路。
+INVALIDPARAMETER_LINEOVERCOUNTED = 'InvalidParameter.LineOverCounted'
+
 # 锁定天数不正确。
 INVALIDPARAMETER_LOCKDAYSINVALID = 'InvalidParameter.LockDaysInvalid'
 
@@ -335,13 +428,19 @@ INVALIDPARAMETER_MXINVALID = 'InvalidParameter.MxInvalid'
 # 新套餐类型无效。
 INVALIDPARAMETER_NEWPACKAGETYPEINVALID = 'InvalidParameter.NewPackageTypeInvalid'
 
+# 您不是源域名所有者，无法复制线路。
+INVALIDPARAMETER_NOAUTHORITYTOSRCDOMAIN = 'InvalidParameter.NoAuthorityToSrcDomain'
+
+# 分组不属于当前域名，请确认您是否有权限修改分组。
+INVALIDPARAMETER_NOAUTHORITYTOTHEGROUP = 'InvalidParameter.NoAuthorityToTheGroup'
+
 # 分页起始数量错误。
 INVALIDPARAMETER_OFFSETINVALID = 'InvalidParameter.OffsetInvalid'
 
 # 无效的openid。
 INVALIDPARAMETER_OPENIDINVALID = 'InvalidParameter.OpenidInvalid'
 
-# 操作失败，请稍候再试。
+# 操作失败，请稍后再试。
 INVALIDPARAMETER_OPERATEFAILED = 'InvalidParameter.OperateFailed'
 
 # 当前操作过于频繁，请 1 分钟后重试。
@@ -368,6 +467,9 @@ INVALIDPARAMETER_PERMISSIONDENIED = 'InvalidParameter.PermissionDenied'
 # 用户UIN无效。
 INVALIDPARAMETER_QCLOUDUININVALID = 'InvalidParameter.QcloudUinInvalid'
 
+# TXT 记录无法匹配，请确认记录值是否准确，并再次验证。
+INVALIDPARAMETER_QUHUITXTNOTMATCH = 'InvalidParameter.QuhuiTxtNotMatch'
+
 # TXT 记录未设置或暂未生效，请稍后重试。
 INVALIDPARAMETER_QUHUITXTRECORDWAIT = 'InvalidParameter.QuhuiTxtRecordWait'
 
@@ -407,6 +509,9 @@ INVALIDPARAMETER_RESULTMORETHAN500 = 'InvalidParameter.ResultMoreThan500'
 # 共享用户中包含未实名认证用户。
 INVALIDPARAMETER_SHAREDUSERSUNREALNAME = 'InvalidParameter.SharedUsersUnrealName'
 
+# 开始时间不能大于结束时间。
+INVALIDPARAMETER_STARTTIMEGREATERTHANENDTIME = 'InvalidParameter.StarttimeGreaterThanEndtime'
+
 # 状态代码不正确。
 INVALIDPARAMETER_STATUSCODEINVALID = 'InvalidParameter.StatusCodeInvalid'
 
@@ -422,12 +527,15 @@ INVALIDPARAMETER_TIMESPANINVALID = 'InvalidParameter.TimeSpanInvalid'
 # 时间戳已过期。
 INVALIDPARAMETER_TIMESTAMPEXPIRED = 'InvalidParameter.TimestampExpired'
 
-# 当前帐号下的无效域名过多，暂时无法使用该功能。请将已有域名的 DNS 服务器正确指向 DNSPod 之后，再尝试添加。
+# 当前账号下的无效域名过多，暂时无法使用该功能。请将已有域名的 DNS 服务器正确指向 DNSPod 之后，再尝试添加。
 INVALIDPARAMETER_TOOMANYINVALIDDOMAINS = 'InvalidParameter.TooManyInvalidDomains'
 
 # 域名无效。
 INVALIDPARAMETER_TOOLSDOMAININVALID = 'InvalidParameter.ToolsDomainInvalid'
 
+# 您要过户到的账号已被系统封禁，如果您有任何疑问请与我们联系。
+INVALIDPARAMETER_TRANSFERACCOUNTISBANNED = 'InvalidParameter.TransferAccountIsBanned'
+
 # 解锁代码已失效。
 INVALIDPARAMETER_UNLOCKCODEEXPIRED = 'InvalidParameter.UnLockCodeExpired'
 
@@ -461,6 +569,12 @@ INVALIDPARAMETERVALUE_DOMAINGRADEINVALID = 'InvalidParameterValue.DomainGradeInv
 # 当前域名有误，请返回重新操作。
 INVALIDPARAMETERVALUE_DOMAINNOTEXISTS = 'InvalidParameterValue.DomainNotExists'
 
+# 自定义线路IP段不能为空。
+INVALIDPARAMETERVALUE_IPAREAEMPTYIP = 'InvalidParameterValue.IpAreaEmptyIp'
+
+# 自定义线路名称不能为空。
+INVALIDPARAMETERVALUE_IPAREAEMPTYLINENAME = 'InvalidParameterValue.IpAreaEmptyLineName'
+
 # 分页长度数量错误。
 INVALIDPARAMETERVALUE_LIMITINVALID = 'InvalidParameterValue.LimitInvalid'
 
@@ -479,6 +593,9 @@ LIMITEXCEEDED_AAAACOUNTLIMIT = 'LimitExceeded.AAAACountLimit'
 # @的NS记录只能设置为默认线路。
 LIMITEXCEEDED_ATNSRECORDLIMIT = 'LimitExceeded.AtNsRecordLimit'
 
+# 抱歉，自定义线路个数超过限制，请联系销售进行购买。
+LIMITEXCEEDED_CUSTOMLINELIMITED = 'LimitExceeded.CustomLineLimited'
+
 # 别名数量已经达到限制。
 LIMITEXCEEDED_DOMAINALIASCOUNTEXCEEDED = 'LimitExceeded.DomainAliasCountExceeded'
 
@@ -497,6 +614,9 @@ LIMITEXCEEDED_HIDDENURLEXCEEDED = 'LimitExceeded.HiddenUrlExceeded'
 # NS记录数量超出限制。
 LIMITEXCEEDED_NSCOUNTLIMIT = 'LimitExceeded.NsCountLimit'
 
+# 分页起始数量过大。
+LIMITEXCEEDED_OFFSETEXCEEDED = 'LimitExceeded.OffsetExceeded'
+
 # 记录的TTL值超出了限制。
 LIMITEXCEEDED_RECORDTTLLIMIT = 'LimitExceeded.RecordTtlLimit'
 
@@ -539,6 +659,9 @@ OPERATIONDENIED_DELETEUSINGRECORDLINENOTALLOWED = 'OperationDenied.DeleteUsingRe
 # 仅域名所有者可进行此操作。
 OPERATIONDENIED_DOMAINOWNERALLOWEDONLY = 'OperationDenied.DomainOwnerAllowedOnly'
 
+# 该线路正在使用当中，不能编辑。
+OPERATIONDENIED_EDITUSINGRECORDLINENOTALLOWED = 'OperationDenied.EditUsingRecordLineNotAllowed'
+
 # 抱歉，不允许添加黑名单中的IP。
 OPERATIONDENIED_IPINBLACKLISTNOTALLOWED = 'OperationDenied.IPInBlacklistNotAllowed'
 
@@ -581,10 +704,10 @@ OPERATIONDENIED_VIPDOMAINALLOWED = 'OperationDenied.VipDomainAllowed'
 # 请求的次数超过了频率限制。
 REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
 
-# 您的IP添加了过多任务，请稍后重试。
+# 您的IP添加了过多任务。每个小时内，一个IP最多可提交80个任务，请稍后重试。
 REQUESTLIMITEXCEEDED_BATCHTASKLIMIT = 'RequestLimitExceeded.BatchTaskLimit'
 
-# 您的帐号在短时间内添加了大量的域名，请控制添加频率。
+# 您的账号在短时间内添加了大量的域名，请控制添加频率。
 REQUESTLIMITEXCEEDED_CREATEDOMAINLIMIT = 'RequestLimitExceeded.CreateDomainLimit'
 
 # API请求次数超出限制。
